// Copied from https://github.com/angular-eslint/angular-eslint/blob/master/packages/eslint-plugin-template/src/utils/create-eslint-rule.ts
import { ESLintUtils } from "@typescript-eslint/utils";
/**
 * We need to patch the RuleCreator in order to preserve the defaultOptions
 * to use as part of documentation generation.
 */
const patchedRuleCreator = (urlCreator) => {
    return function createRule({ name, meta, defaultOptions, create }) {
        return {
            meta: Object.assign(Object.assign({}, meta), {
                docs: Object.assign(Object.assign({}, meta.docs), {
                    url: urlCreator(name),
                }),
            }),
            defaultOptions,
            // eslint-disable-next-line @typescript-eslint/explicit-function-return-type
            create(context) {
                const optionsWithDefault = ESLintUtils.applyDefault(defaultOptions, context.options);
                return create(context, optionsWithDefault);
            },
        };
    };
};
patchedRuleCreator.withoutDocs = ESLintUtils.RuleCreator.withoutDocs;
export const createESLintRule = patchedRuleCreator((_ruleName) => `https://github.com/jerone/eslint-plugin-angular-template-consistent-this/blob/master/docs/rules/eslint-plugin-angular-template-consistent-this.md`);
export function getTemplateParserServices(context) {
    ensureTemplateParser(context);
    return context.parserServices;
}
/**
 * Utility for rule authors to ensure that their rule is correctly being used with @angular-eslint/template-parser
 * If @angular-eslint/template-parser is not the configured parser when the function is invoked it will throw
 */
export function ensureTemplateParser(context) {
    var _a, _b;
    if (!((_a = context.parserServices) === null || _a === void 0 ? void 0 : _a.convertNodeSourceSpanToLoc) ||
        !((_b = context.parserServices) === null || _b === void 0 ? void 0 : _b.convertElementSourceSpanToLoc)) {
        /**
         * The user needs to have configured "parser" in their eslint config and set it
         * to @angular-eslint/template-parser
         */
        throw new Error("You have used a rule which requires '@angular-eslint/template-parser' to be used as the 'parser' in your ESLint config.");
    }
}
